@@ -179,11 +179,12 @@ bool BrowseBonjour::browse(const string& serviceName, mDNSResult& result, int /*
         CHECKED(DNSServiceBrowse(
             service.get(), 0, 0, serviceName.c_str(), "local.",
             [](DNSServiceRef /*service*/, DNSServiceFlags /*flags*/, uint32_t /*interfaceIndex*/, DNSServiceErrorType errorCode, const char* serviceName,
-               const char* regtype, const char* replyDomain, void* context) {
-                auto replyCollection = static_cast<deque<mDNSReply>*>(context);
+               const char* regtype, const char* replyDomain, void* context)
+            {
+            auto replyCollection = static_cast<deque<mDNSReply>*>(context);
 
-                CHECKED(errorCode);
-                replyCollection->push_back(mDNSReply{string(serviceName), string(regtype), string(replyDomain)});
+            CHECKED(errorCode);
+            replyCollection->push_back(mDNSReply{string(serviceName), string(regtype), string(replyDomain)});
             },
             &replyCollection));
 
@@ -198,11 +199,12 @@ bool BrowseBonjour::browse(const string& serviceName, mDNSResult& result, int /*
             CHECKED(DNSServiceResolve(
                 service.get(), 0, 0, reply.name.c_str(), reply.regtype.c_str(), reply.domain.c_str(),
                 [](DNSServiceRef /*service*/, DNSServiceFlags /*flags*/, uint32_t /*interfaceIndex*/, DNSServiceErrorType errorCode, const char* /*fullName*/,
-                   const char* hosttarget, uint16_t port, uint16_t /*txtLen*/, const unsigned char* /*txtRecord*/, void* context) {
-                    auto resultCollection = static_cast<deque<mDNSResolve>*>(context);
+                   const char* hosttarget, uint16_t port, uint16_t /*txtLen*/, const unsigned char* /*txtRecord*/, void* context)
+                {
+                auto resultCollection = static_cast<deque<mDNSResolve>*>(context);
 
-                    CHECKED(errorCode);
-                    resultCollection->push_back(mDNSResolve{string(hosttarget), ntohs(port)});
+                CHECKED(errorCode);
+                resultCollection->push_back(mDNSResolve{string(hosttarget), ntohs(port)});
                 },
                 &resolveCollection));
 
@@ -220,20 +222,21 @@ bool BrowseBonjour::browse(const string& serviceName, mDNSResult& result, int /*
             CHECKED(DNSServiceGetAddrInfo(
                 service.get(), kDNSServiceFlagsLongLivedQuery, 0, kDNSServiceProtocol_IPv4, resolve.fullName.c_str(),
                 [](DNSServiceRef /*service*/, DNSServiceFlags /*flags*/, uint32_t interfaceIndex, DNSServiceErrorType /*errorCode*/, const char* hostname,
-                   const sockaddr* address, uint32_t /*ttl*/, void* context) {
-                    auto result = static_cast<mDNSResult*>(context);
+                   const sockaddr* address, uint32_t /*ttl*/, void* context)
+                {
+                auto result = static_cast<mDNSResult*>(context);
 
-                    result->host = string(hostname);
-                    result->ip_version = (address->sa_family == AF_INET) ? (IPVersion::IPv4) : (IPVersion::IPv6);
-                    result->iface_idx = static_cast<int>(interfaceIndex);
+                result->host = string(hostname);
+                result->ip_version = (address->sa_family == AF_INET) ? (IPVersion::IPv4) : (IPVersion::IPv6);
+                result->iface_idx = static_cast<int>(interfaceIndex);
 
-                    char hostIP[NI_MAXHOST];
-                    char hostService[NI_MAXSERV];
-                    if (getnameinfo(address, sizeof(*address), hostIP, sizeof(hostIP), hostService, sizeof(hostService), NI_NUMERICHOST | NI_NUMERICSERV) == 0)
-                        result->ip = string(hostIP);
-                    else
-                        return;
-                    result->valid = true;
+                char hostIP[NI_MAXHOST];
+                char hostService[NI_MAXSERV];
+                if (getnameinfo(address, sizeof(*address), hostIP, sizeof(hostIP), hostService, sizeof(hostService), NI_NUMERICHOST | NI_NUMERICSERV) == 0)
+                    result->ip = string(hostIP);
+                else
+                    return;
+                result->valid = true;
                 },
                 &resultCollection[i++]));
         }
