@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2023  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,11 @@
 #define NOMINMAX
 #endif // NOMINMAX
 
+// prototype/interface header file
 #include "controller.hpp"
+
+// local headers
+#include "decoder/null_decoder.hpp"
 #include "decoder/pcm_decoder.hpp"
 #if defined(HAS_OGG) && (defined(HAS_TREMOR) || defined(HAS_VORBIS))
 #include "decoder/ogg_decoder.hpp"
@@ -54,12 +58,13 @@
 
 #include "browseZeroConf/browse_mdns.hpp"
 #include "common/aixlog.hpp"
+#include "common/message/client_info.hpp"
+#include "common/message/hello.hpp"
+#include "common/message/time.hpp"
 #include "common/snap_exception.hpp"
-#include "message/client_info.hpp"
-#include "message/hello.hpp"
-#include "message/time.hpp"
 #include "time_provider.hpp"
 
+// standard headers
 #include <algorithm>
 #include <iostream>
 #include <memory>
@@ -117,7 +122,9 @@ std::vector<std::string> Controller::getSupportedPlayerNames()
 
 void Controller::getNextMessage()
 {
-    clientConnection_->getNextMessage([this](const boost::system::error_code& ec, std::unique_ptr<msg::BaseMessage> response) {
+    clientConnection_->getNextMessage(
+        [this](const boost::system::error_code& ec, std::unique_ptr<msg::BaseMessage> response)
+        {
         if (ec)
         {
             reconnect();
@@ -179,6 +186,8 @@ void Controller::getNextMessage()
             else if (headerChunk_->codec == "opus")
                 decoder_ = make_unique<decoder::OpusDecoder>();
 #endif
+            else if (headerChunk_->codec == "null")
+                decoder_ = make_unique<decoder::NullDecoder>();
             else
                 throw SnapException("codec not supported: \"" + headerChunk_->codec + "\"");
 
@@ -218,7 +227,9 @@ void Controller::getNextMessage()
             if (!player_)
                 throw SnapException("No audio player support" + (settings_.player.player_name.empty() ? "" : " for: " + settings_.player.player_name));
 
-            player_->setVolumeCallback([this](double volume, bool muted) {
+            player_->setVolumeCallback(
+                [this](double volume, bool muted)
+                {
                 static double last_volume(-1);
                 static bool last_muted(true);
                 if ((volume != last_volume) || (last_muted != muted))
@@ -228,7 +239,9 @@ void Controller::getNextMessage()
                     auto info = std::make_shared<msg::ClientInfo>();
                     info->setVolume(static_cast<uint16_t>(volume * 100.));
                     info->setMuted(muted);
-                    clientConnection_->send(info, [this](const boost::system::error_code& ec) {
+                    clientConnection_->send(info,
+                                            [this](const boost::system::error_code& ec)
+                                            {
                         if (ec)
                         {
                             LOG(ERROR, LOG_TAG) << "Failed to send client info, error: " << ec.message() << "\n";
@@ -246,14 +259,6 @@ void Controller::getNextMessage()
             player_->setVolume(serverSettings_->getVolume() / 100., serverSettings_->isMuted());
             // }
         }
-        // else if (response->type == message_type::kStreamTags)
-        // {
-        //     if (meta_)
-        //     {
-        //         auto stream_tags = msg::message_cast<msg::StreamTags>(std::move(response));
-        //         meta_->push(stream_tags->msg);
-        //     }
-        // }
         else
         {
             LOG(WARNING, LOG_TAG) << "Unexpected message received, type: " << response->type << "\n";
@@ -266,35 +271,38 @@ void Controller::getNextMessage()
 void Controller::sendTimeSyncMessage(int quick_syncs)
 {
     auto timeReq = std::make_shared<msg::Time>();
-    clientConnection_->sendRequest<msg::Time>(
-        timeReq, 2s, [this, quick_syncs](const boost::system::error_code& ec, const std::unique_ptr<msg::Time>& response) mutable {
-            if (ec)
-            {
-                LOG(ERROR, LOG_TAG) << "Time sync request failed: " << ec.message() << "\n";
-                reconnect();
-                return;
-            }
-            else
-            {
-                TimeProvider::getInstance().setDiff(response->latency, response->received - response->sent);
-            }
+    clientConnection_->sendRequest<msg::Time>(timeReq, 2s,
+                                              [this, quick_syncs](const boost::system::error_code& ec, const std::unique_ptr<msg::Time>& response) mutable
+                                              {
+        if (ec)
+        {
+            LOG(ERROR, LOG_TAG) << "Time sync request failed: " << ec.message() << "\n";
+            reconnect();
+            return;
+        }
+        else
+        {
+            TimeProvider::getInstance().setDiff(response->latency, response->received - response->sent);
+        }
 
-            std::chrono::microseconds next = TIME_SYNC_INTERVAL;
-            if (quick_syncs > 0)
+        std::chrono::microseconds next = TIME_SYNC_INTERVAL;
+        if (quick_syncs > 0)
+        {
+            if (--quick_syncs == 0)
+                LOG(INFO, LOG_TAG) << "diff to server [ms]: "
+                                   << static_cast<float>(TimeProvider::getInstance().getDiffToServer<chronos::usec>().count()) / 1000.f << "\n";
+            next = 100us;
+        }
+        timer_.expires_after(next);
+        timer_.async_wait(
+            [this, quick_syncs](const boost::system::error_code& ec)
             {
-                if (--quick_syncs == 0)
-                    LOG(INFO, LOG_TAG) << "diff to server [ms]: "
-                                       << static_cast<float>(TimeProvider::getInstance().getDiffToServer<chronos::usec>().count()) / 1000.f << "\n";
-                next = 100us;
+            if (!ec)
+            {
+                sendTimeSyncMessage(quick_syncs);
             }
-            timer_.expires_after(next);
-            timer_.async_wait([this, quick_syncs](const boost::system::error_code& ec) {
-                if (!ec)
-                {
-                    sendTimeSyncMessage(quick_syncs);
-                }
-            });
         });
+    });
 }
 
 void Controller::browseMdns(const MdnsHandler& handler)
@@ -320,7 +328,9 @@ void Controller::browseMdns(const MdnsHandler& handler)
     }
 
     timer_.expires_after(500ms);
-    timer_.async_wait([this, handler](const boost::system::error_code& ec) {
+    timer_.async_wait(
+        [this, handler](const boost::system::error_code& ec)
+        {
         if (!ec)
         {
             browseMdns(handler);
@@ -339,7 +349,9 @@ void Controller::start()
 {
     if (settings_.server.host.empty())
     {
-        browseMdns([this](const boost::system::error_code& ec, const std::string& host, uint16_t port) {
+        browseMdns(
+            [this](const boost::system::error_code& ec, const std::string& host, uint16_t port)
+            {
             if (ec)
             {
                 LOG(ERROR, LOG_TAG) << "Failed to browse MDNS, error: " << ec.message() << "\n";
@@ -376,7 +388,9 @@ void Controller::reconnect()
     stream_.reset();
     decoder_.reset();
     timer_.expires_after(1s);
-    timer_.async_wait([this](const boost::system::error_code& ec) {
+    timer_.async_wait(
+        [this](const boost::system::error_code& ec)
+        {
         if (!ec)
         {
             worker();
@@ -386,7 +400,9 @@ void Controller::reconnect()
 
 void Controller::worker()
 {
-    clientConnection_->connect([this](const boost::system::error_code& ec) {
+    clientConnection_->connect(
+        [this](const boost::system::error_code& ec)
+        {
         if (!ec)
         {
             // LOG(INFO, LOG_TAG) << "Connected!\n";
@@ -397,19 +413,21 @@ void Controller::worker()
             // Say hello to the server
             auto hello = std::make_shared<msg::Hello>(macAddress, settings_.host_id, settings_.instance);
             clientConnection_->sendRequest<msg::ServerSettings>(
-                hello, 2s, [this](const boost::system::error_code& ec, std::unique_ptr<msg::ServerSettings> response) mutable {
-                    if (ec)
-                    {
-                        LOG(ERROR, LOG_TAG) << "Failed to send hello request, error: " << ec.message() << "\n";
-                        reconnect();
-                        return;
-                    }
-                    else
-                    {
-                        serverSettings_ = std::move(response);
-                        LOG(INFO, LOG_TAG) << "ServerSettings - buffer: " << serverSettings_->getBufferMs() << ", latency: " << serverSettings_->getLatency()
-                                           << ", volume: " << serverSettings_->getVolume() << ", muted: " << serverSettings_->isMuted() << "\n";
-                    }
+                hello, 2s,
+                [this](const boost::system::error_code& ec, std::unique_ptr<msg::ServerSettings> response) mutable
+                {
+                if (ec)
+                {
+                    LOG(ERROR, LOG_TAG) << "Failed to send hello request, error: " << ec.message() << "\n";
+                    reconnect();
+                    return;
+                }
+                else
+                {
+                    serverSettings_ = std::move(response);
+                    LOG(INFO, LOG_TAG) << "ServerSettings - buffer: " << serverSettings_->getBufferMs() << ", latency: " << serverSettings_->getLatency()
+                                       << ", volume: " << serverSettings_->getVolume() << ", muted: " << serverSettings_->isMuted() << "\n";
+                }
                 });
 
             // Do initial time sync with the server
