@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,13 +16,20 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+// prototype/interface header file
 #include "alsa_player.hpp"
+
+// local headers
 #include "common/aixlog.hpp"
 #include "common/snap_exception.hpp"
 #include "common/str_compat.hpp"
 #include "common/utils/logging.hpp"
 #include "common/utils/string_utils.hpp"
 
+// 3rd party headers
+
+// standard headers
+
 using namespace std::chrono_literals;
 using namespace std;
 
@@ -181,7 +188,9 @@ bool AlsaPlayer::getHardwareVolume(double& volume, bool& muted)
 
 void AlsaPlayer::waitForEvent()
 {
-    sd_.async_wait(boost::asio::posix::stream_descriptor::wait_read, [this](const boost::system::error_code& ec) {
+    sd_.async_wait(boost::asio::posix::stream_descriptor::wait_read,
+                   [this](const boost::system::error_code& ec)
+                   {
         if (ec)
         {
             // TODO: fd is "Bad" after unplugging/plugging USB DAC, i.e. after init/uninit/init cycle
@@ -214,7 +223,9 @@ void AlsaPlayer::waitForEvent()
                 // As workaround we defer getting the volume by 20ms.
                 timer_.cancel();
                 timer_.expires_after(20ms);
-                timer_.async_wait([this](const boost::system::error_code& ec) {
+                timer_.async_wait(
+                    [this](const boost::system::error_code& ec)
+                    {
                     if (!ec)
                     {
                         if (getHardwareVolume(volume_, muted_))
@@ -242,7 +253,9 @@ void AlsaPlayer::initMixer()
         throw SnapException("Can't open control for " + mixer_device_ + ", error: " + snd_strerror(err));
     if ((err = snd_ctl_subscribe_events(ctl_, 1)) < 0)
         throw SnapException("Can't subscribe for events for " + mixer_device_ + ", error: " + snd_strerror(err));
-    fd_ = std::unique_ptr<pollfd, std::function<void(pollfd*)>>(new pollfd(), [](pollfd* p) {
+    fd_ = std::unique_ptr<pollfd, std::function<void(pollfd*)>>(new pollfd(),
+                                                                [](pollfd* p)
+                                                                {
         close(p->fd);
         delete p;
     });
