@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,9 +19,15 @@
 #ifndef ALSA_PLAYER_HPP
 #define ALSA_PLAYER_HPP
 
+// local headers
 #include "player.hpp"
 
+// 3rd party headers
 #include <alsa/asoundlib.h>
+#include <boost/asio/posix/stream_descriptor.hpp>
+#include <boost/asio/steady_timer.hpp>
+
+// standard headers
 #include <chrono>
 #include <optional>
 
