@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,13 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#include <chrono>
-#include <iostream>
-#ifndef WINDOWS
-#include <csignal>
-#include <sys/resource.h>
-#endif
-
+// local headers
 #include "common/popl.hpp"
 #include "controller.hpp"
 
@@ -46,9 +40,19 @@
 #include "common/utils.hpp"
 #include "common/version.hpp"
 
+// 3rd party headers
 #include <boost/asio/ip/host_name.hpp>
 #include <boost/asio/signal_set.hpp>
 
+// standard headers
+#include <chrono>
+#include <iostream>
+#ifndef WINDOWS
+#include <csignal>
+#include <sys/resource.h>
+#endif
+
+
 using namespace std;
 using namespace popl;
 using namespace player;
@@ -200,7 +204,7 @@ int main(int argc, char** argv)
         if (versionSwitch->is_set())
         {
             cout << "snapclient v" << version::code << (!version::rev().empty() ? (" (rev " + version::rev(8) + ")") : ("")) << "\n"
-                 << "Copyright (C) 2014-2021 BadAix (snapcast@badaix.de).\n"
+                 << "Copyright (C) 2014-2022 BadAix (snapcast@badaix.de).\n"
                  << "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.\n"
                  << "This is free software: you are free to change and redistribute it.\n"
                  << "There is NO WARRANTY, to the extent permitted by law.\n\n"
@@ -414,7 +418,9 @@ int main(int argc, char** argv)
         boost::asio::io_context io_context;
         // Construct a signal set registered for process termination.
         boost::asio::signal_set signals(io_context, SIGHUP, SIGINT, SIGTERM);
-        signals.async_wait([&](const boost::system::error_code& ec, int signal) {
+        signals.async_wait(
+            [&](const boost::system::error_code& ec, int signal)
+            {
             if (!ec)
                 LOG(INFO, LOG_TAG) << "Received signal " << signal << ": " << strsignal(signal) << "\n";
             else
