@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,9 +16,10 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef TIME_MSG_H
-#define TIME_MSG_H
+#ifndef MESSAGE_TIME_HPP
+#define MESSAGE_TIME_HPP
 
+// local headers
 #include "message.hpp"
 
 namespace msg
