@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,14 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef WIRE_CHUNK_H
-#define WIRE_CHUNK_H
+#ifndef MESSAGE_WIRE_CHUNK_HPP
+#define MESSAGE_WIRE_CHUNK_HPP
 
+// local headers
 #include "common/time_defs.hpp"
 #include "message.hpp"
+
+// standard headers
 #include <chrono>
 #include <cstdlib>
 #include <cstring>
