@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2023  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,22 +16,28 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef CONTROL_SERVER_H
-#define CONTROL_SERVER_H
+#ifndef CONTROL_SERVER_HPP
+#define CONTROL_SERVER_HPP
 
-#include <boost/asio.hpp>
+// local headers
+#include "common/message/codec_header.hpp"
+#include "common/message/message.hpp"
+#include "common/message/server_settings.hpp"
+#include "common/queue.h"
+#include "common/sample_format.hpp"
+#include "control_session.hpp"
+#include "server_settings.hpp"
+
+// 3rd party headers
+#include <boost/asio/io_context.hpp>
+#include <boost/asio/ip/tcp.hpp>
+
+// standard headers
 #include <memory>
 #include <mutex>
 #include <set>
 #include <vector>
 
-#include "common/queue.h"
-#include "common/sample_format.hpp"
-#include "control_session.hpp"
-#include "message/codec_header.hpp"
-#include "message/message.hpp"
-#include "message/server_settings.hpp"
-#include "server_settings.hpp"
 
 using boost::asio::ip::tcp;
 using acceptor_ptr = std::unique_ptr<tcp::acceptor>;
