@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2023  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,14 +16,18 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef CONTROL_SESSION_H
-#define CONTROL_SESSION_H
+#ifndef CONTROL_SESSION_HPP
+#define CONTROL_SESSION_HPP
 
+// local headers
+#include "common/message/message.hpp"
 #include "common/queue.h"
-#include "message/message.hpp"
 #include "server_settings.hpp"
+
+// 3rd party headers
+
+// standard headers
 #include <atomic>
-#include <boost/asio.hpp>
 #include <condition_variable>
 #include <memory>
 #include <set>
