@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,11 +19,19 @@
 #ifndef CONTROL_SESSION_TCP_HPP
 #define CONTROL_SESSION_TCP_HPP
 
+// local headers
 #include "control_session.hpp"
+
+// 3rd party headers
+#include <boost/asio/any_io_executor.hpp>
+#include <boost/asio/ip/tcp.hpp>
+#include <boost/asio/strand.hpp>
+#include <boost/asio/streambuf.hpp>
+
+// standard headers
 #include <deque>
 
 using boost::asio::ip::tcp;
-namespace net = boost::asio;
 
 /// Endpoint for a connected control client.
 /**
@@ -49,7 +57,7 @@ protected:
 
     tcp::socket socket_;
     boost::asio::streambuf streambuf_;
-    net::strand<net::any_io_executor> strand_;
+    boost::asio::strand<boost::asio::any_io_executor> strand_;
     std::deque<std::string> messages_;
 };
 
