@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2023  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,20 +16,26 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
+// prototype/interface header file
 #include "stream_session.hpp"
 
+// local headers
 #include "common/aixlog.hpp"
-#include "message/pcm_chunk.hpp"
+#include "common/message/pcm_chunk.hpp"
+
+// 3rd party headers
+
+// standard headers
 #include <iostream>
 
 using namespace std;
 using namespace streamreader;
 
-
 static constexpr auto LOG_TAG = "StreamSession";
 
 
-StreamSession::StreamSession(boost::asio::io_context& ioc, StreamMessageReceiver* receiver) : messageReceiver_(receiver), pcmStream_(nullptr), strand_(ioc)
+StreamSession::StreamSession(const boost::asio::any_io_executor& executor, StreamMessageReceiver* receiver)
+    : messageReceiver_(receiver), pcmStream_(nullptr), strand_(boost::asio::make_strand(executor))
 {
     base_msg_size_ = baseMessage_.getSize();
     buffer_.resize(base_msg_size_);
@@ -38,12 +44,14 @@ StreamSession::StreamSession(boost::asio::io_context& ioc, StreamMessageReceiver
 
 void StreamSession::setPcmStream(PcmStreamPtr pcmStream)
 {
+    std::lock_guard<std::mutex> lock(mutex_);
     pcmStream_ = pcmStream;
 }
 
 
 const PcmStreamPtr StreamSession::pcmStream() const
 {
+    std::lock_guard<std::mutex> lock(mutex_);
     return pcmStream_;
 }
 
@@ -52,8 +60,12 @@ void StreamSession::send_next()
 {
     auto& buffer = messages_.front();
     buffer.on_air = true;
-    strand_.post([this, self = shared_from_this(), buffer]() {
-        sendAsync(buffer, [this](boost::system::error_code ec, std::size_t length) {
+    boost::asio::post(strand_,
+                      [this, self = shared_from_this(), buffer]()
+                      {
+        sendAsync(buffer,
+                  [this](boost::system::error_code ec, std::size_t length)
+                  {
             messages_.pop_front();
             if (ec)
             {
@@ -70,16 +82,19 @@ void StreamSession::send_next()
 
 void StreamSession::send(shared_const_buffer const_buf)
 {
-    strand_.post([this, self = shared_from_this(), const_buf]() {
+    boost::asio::post(strand_,
+                      [this, self = shared_from_this(), const_buf]()
+                      {
         // delete PCM chunks that are older than the overall buffer duration
         messages_.erase(std::remove_if(messages_.begin(), messages_.end(),
-                                       [this](const shared_const_buffer& buffer) {
-                                           const auto& msg = buffer.message();
-                                           if (!msg.is_pcm_chunk || buffer.on_air)
-                                               return false;
-                                           auto age = chronos::clk::now() - msg.rec_time;
-                                           return (age > std::chrono::milliseconds(bufferMs_) + 100ms);
-                                       }),
+                                       [this](const shared_const_buffer& buffer)
+                                       {
+            const auto& msg = buffer.message();
+            if (!msg.is_pcm_chunk || buffer.on_air)
+                return false;
+            auto age = chronos::clk::now() - msg.rec_time;
+            return (age > std::chrono::milliseconds(bufferMs_) + 100ms);
+                        }),
                         messages_.end());
 
         messages_.push_back(const_buf);
