@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,8 +19,14 @@
 #ifndef STREAM_SESSION_TCP_HPP
 #define STREAM_SESSION_TCP_HPP
 
+// local headers
 #include "stream_session.hpp"
 
+// 3rd party headers
+#include <boost/asio/ip/tcp.hpp>
+
+// standard headers
+
 using boost::asio::ip::tcp;
 
 
