@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2023  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #include "common/utils/string_utils.hpp"
 
 // standard headers
-#include <regex>
+#include <exception>
 
 
 using namespace std;
@@ -37,6 +37,7 @@ namespace streamreader
 
 static constexpr auto LOG_TAG = "LibrespotStream";
 
+// https://commons.wikimedia.org/wiki/File:Spotify_logo_without_text.svg
 static constexpr auto SPOTIFY_LOGO = "PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9Im5vIj8+Cjxz"
                                      "dmcgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIiBoZWlnaHQ9IjE2OHB4IiB3aWR0"
                                      "aD0iMTY4cHgiIHZlcnNpb249IjEuMSIgdmlld0JveD0iMCAwIDE2OCAxNjgiPgogPHBhdGggZmls"
@@ -95,7 +96,7 @@ LibrespotStream::LibrespotStream(PcmStream::Listener* pcmListener, boost::asio::
     if (normalize)
         params_ += " --enable-volume-normalisation";
     if (autoplay)
-        params_ += " --autoplay";
+        params_ += " --autoplay on";
     params_ += " --verbose";
 
     if (uri_.query.find("username") != uri_.query.end())
@@ -130,29 +131,31 @@ void LibrespotStream::initExeAndPath(const std::string& filename)
     }
 }
 
-
 void LibrespotStream::onStderrMsg(const std::string& line)
 {
-    // Watch stderr for 'Loading track' messages and set the stream metadata
-    // For more than track name check: https://github.com/plietar/librespot/issues/154
-
-    /// Watch will kill librespot if there was no message received for 130min
-    // 2021-05-09 09-25-48.651 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z DEBUG librespot_playback::player] command=Load(SpotifyId
-    // 2021-05-09 09-25-48.651 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z TRACE librespot_connect::spirc] Sending status to server
-    // 2021-05-09 09-25-48.746 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z WARN  librespot_connect::spirc] No autoplay_uri found
-    // 2021-05-09 09-25-48.747 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z ERROR librespot_connect::spirc] AutoplayError: MercuryError
-    // 2021-05-09 09-25-48.750 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z INFO  librespot_playback::player] Loading <Big Gangsta>
-
-    // Parse log level, source and message from the log line
-    // Format: [2021-05-09T08:31:08Z DEBUG librespot_playback::player] new Player[0]
-
-    smatch m;
-    static regex re_log_line(R"(\[(\S+)(\s+)(\bTRACE\b|\bDEBUG\b|\bINFO\b|\bWARN\b|\bERROR\b)(\s+)(.*)\] (.*))");
-    if (regex_search(line, m, re_log_line) && (m.size() == 7))
+    try
     {
-        const std::string& level = m[3];
-        const std::string& source = m[5];
-        const std::string& message = m[6];
+        // Watch stderr for 'Loading track' messages and set the stream metadata
+        // For more than track name check: https://github.com/plietar/librespot/issues/154
+
+        /// Watch will kill librespot if there was no message received for 130min
+        // 2021-05-09 09-25-48.651 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z DEBUG librespot_playback::player] command=Load(SpotifyId
+        // 2021-05-09 09-25-48.651 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z TRACE librespot_connect::spirc] Sending status to server
+        // 2021-05-09 09-25-48.746 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z WARN  librespot_connect::spirc] No autoplay_uri found
+        // 2021-05-09 09-25-48.747 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z ERROR librespot_connect::spirc] AutoplayError: MercuryError
+        // 2021-05-09 09-25-48.750 [Info] (LibrespotStream) (Spotify) [2021-05-09T07:25:48Z INFO  librespot_playback::player] Loading <Big Gangsta>
+
+        // Parse log level, source and message from the log line
+        // Format: [2021-05-09T08:31:08Z DEBUG librespot_playback::player] new Player[0]
+
+        // std::cerr << "Librespot: " << line << "\n";
+        std::string message = line;
+        utils::string::split_left(message, ' ', message);
+        std::string level = utils::string::trim_copy(utils::string::split_left(message, ' ', message));
+        std::string source = utils::string::trim_copy(utils::string::split_left(message, ']', message));
+        utils::string::trim(message);
+
+        bool parsed = true;
         AixLog::Severity severity = AixLog::Severity::info;
         if (level == "TRACE")
             severity = AixLog::Severity::trace;
@@ -164,44 +167,45 @@ void LibrespotStream::onStderrMsg(const std::string& line)
             severity = AixLog::Severity::warning;
         else if (level == "ERROR")
             severity = AixLog::Severity::error;
+        else
+            parsed = false;
 
-        LOG(severity, source) << message << "\n";
-    }
-    else
-        LOG(INFO, LOG_TAG) << "(" << getName() << ") " << line << "\n";
+        if (parsed)
+        {
+            LOG(severity, source) << message << "\n";
+            // std::cerr << "Parsed: " << "Severity: " << severity << ", source: " << source << ", msg: " << message << "\n";
+        }
+        else
+        {
+            return;
+            // LOG(INFO, LOG_TAG) << "(" << getName() << ") " << line << "\n";
+        }
 
-    // Librespot patch:
-    // 	info!("metadata:{{\"ARTIST\":\"{}\",\"TITLE\":\"{}\"}}", artist.name, track.name);
-    // non patched:
-    //  [2021-06-04T07:20:47Z INFO  librespot_playback::player] <Tunnel> (310573 ms) loaded
-    // 	info!("Track \"{}\" loaded", track.name);
-    // std::cerr << line << "\n";
-    static regex re_patched("metadata:(.*)");
-    static regex re_track_loaded(R"( <(.*)> \((.*) ms\) loaded)");
-    // Parse the patched version
-    if (regex_search(line, m, re_patched))
-    {
-        // Patched version
-        LOG(INFO, LOG_TAG) << "metadata: <" << m[1] << ">\n";
-        json j = json::parse(m[1].str());
-        Metadata meta;
-        meta.artist = std::vector<std::string>{j["ARTIST"].get<std::string>()};
-        meta.title = j["TITLE"].get<std::string>();
-        meta.art_data = {SPOTIFY_LOGO, "svg"};
-        Properties properties;
-        properties.metadata = std::move(meta);
-        setProperties(properties);
+        //  [2021-06-04T07:20:47Z INFO  librespot_playback::player] <Tunnel> (310573 ms) loaded
+        // 	info!("Track \"{}\" loaded", track.name);
+        size_t title_pos = 0;
+        size_t ms_pos = 0;
+        size_t n = 0;
+        if (((title_pos = line.find("<")) != std::string::npos) && ((n = line.find(">", title_pos)) != std::string::npos) &&
+            ((ms_pos = line.find("(", n)) != std::string::npos) && ((n = line.find("ms) loaded", ms_pos)) != std::string::npos))
+        {
+            title_pos += 1;
+            std::string title = line.substr(title_pos, line.find(">", title_pos) - title_pos);
+            LOG(INFO, LOG_TAG) << "metadata: <" << title << ">\n";
+            ms_pos += 1;
+            std::string ms = line.substr(ms_pos, n - ms_pos - 1);
+            Metadata meta;
+            meta.title = title;
+            meta.duration = cpt::stod(ms) / 1000.;
+            meta.art_data = {SPOTIFY_LOGO, "svg"};
+            Properties properties;
+            properties.metadata = std::move(meta);
+            setProperties(properties);
+        }
     }
-    else if (regex_search(line, m, re_track_loaded))
+    catch (const std::exception& e)
     {
-        LOG(INFO, LOG_TAG) << "metadata: <" << m[1] << ">\n";
-        Metadata meta;
-        meta.title = string(m[1]);
-        meta.duration = cpt::stod(m[2]) / 1000.;
-        meta.art_data = {SPOTIFY_LOGO, "svg"};
-        Properties properties;
-        properties.metadata = std::move(meta);
-        setProperties(properties);
+        LOG(ERROR, LOG_TAG) << "Exception: " << e.what() << std::endl;
     }
 }
 
