@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2021  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -45,8 +45,8 @@ static constexpr auto LOG_TAG = "PcmStream";
 
 
 PcmStream::PcmStream(PcmStream::Listener* pcmListener, boost::asio::io_context& ioc, const ServerSettings& server_settings, const StreamUri& uri)
-    : active_(false), strand_(net::make_strand(ioc.get_executor())), pcmListeners_{pcmListener}, uri_(uri), chunk_ms_(20), state_(ReaderState::kIdle),
-      ioc_(ioc), server_settings_(server_settings), req_id_(0), property_timer_(strand_)
+    : active_(false), strand_(boost::asio::make_strand(ioc.get_executor())), pcmListeners_{pcmListener}, uri_(uri), chunk_ms_(20), state_(ReaderState::kIdle),
+      server_settings_(server_settings), req_id_(0), property_timer_(strand_)
 {
     encoder::EncoderFactory encoderFactory;
     if (uri_.query.find(kUriCodec) == uri_.query.end())
@@ -64,7 +64,10 @@ PcmStream::PcmStream(PcmStream::Listener* pcmListener, boost::asio::io_context&
 
     if (uri_.query.find(kControlScript) != uri_.query.end())
     {
-        stream_ctrl_ = std::make_unique<ScriptStreamControl>(strand_, uri_.query[kControlScript]);
+        std::string params;
+        if (uri_.query.find(kControlScriptParams) != uri_.query.end())
+            params = uri_.query[kControlScriptParams];
+        stream_ctrl_ = std::make_unique<ScriptStreamControl>(strand_, uri_.query[kControlScript], params);
     }
 
     if (uri_.query.find(kUriChunkMs) != uri_.query.end())
@@ -124,10 +127,14 @@ void PcmStream::onControlRequest(const jsonrpcpp::Request& request)
 void PcmStream::pollProperties()
 {
     property_timer_.expires_after(10s);
-    property_timer_.async_wait([this](const boost::system::error_code& ec) {
+    property_timer_.async_wait(
+        [this](const boost::system::error_code& ec)
+        {
         if (!ec)
         {
-            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"}, [this](const jsonrpcpp::Response& response) {
+            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"},
+                                  [this](const jsonrpcpp::Response& response)
+                                  {
                 LOG(INFO, LOG_TAG) << "Response for Plugin.Stream.Player.GetProperties: " << response.to_json() << "\n";
                 if (response.error().code() == 0)
                     setProperties(response.result());
@@ -151,7 +158,9 @@ void PcmStream::onControlNotification(const jsonrpcpp::Notification& notificatio
         else if (notification.method() == "Plugin.Stream.Ready")
         {
             LOG(DEBUG, LOG_TAG) << "Plugin is ready\n";
-            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"}, [this](const jsonrpcpp::Response& response) {
+            stream_ctrl_->command({++req_id_, "Plugin.Stream.Player.GetProperties"},
+                                  [this](const jsonrpcpp::Response& response)
+                                  {
                 LOG(INFO, LOG_TAG) << "Response for Plugin.Stream.Player.GetProperties: " << response.to_json() << "\n";
                 if (response.error().code() == 0)
                     setProperties(response.result());
@@ -248,8 +257,8 @@ void PcmStream::setState(ReaderState newState)
 void PcmStream::chunkEncoded(const encoder::Encoder& encoder, std::shared_ptr<msg::PcmChunk> chunk, double duration)
 {
     std::ignore = encoder;
-    // LOG(TRACE, LOG_TAG) << "onChunkEncoded: " << getName() << ", duration: " << duration << " ms, compression ratio: " << 100 - ceil(100 *
-    // (chunk->durationMs() / duration)) << "%\n";
+    // LOG(TRACE, LOG_TAG) << "onChunkEncoded: " << getName() << ", duration: " << duration
+    //                     << " ms, compression ratio: " << 100 - ceil(100 * (chunk->durationMs() / duration)) << "%\n";
     if (duration <= 0)
         return;
 
@@ -344,6 +353,15 @@ void PcmStream::setVolume(uint16_t volume, ResultHandler handler)
 }
 
 
+void PcmStream::setMute(bool mute, ResultHandler handler)
+{
+    LOG(DEBUG, LOG_TAG) << "setMute: " << mute << "\n";
+    if (!properties_.can_control)
+        return handler({ControlErrc::can_control_is_false});
+    sendRequest("Plugin.Stream.Player.SetProperty", {"mute", mute}, std::move(handler));
+}
+
+
 void PcmStream::setRate(float rate, ResultHandler handler)
 {
     LOG(DEBUG, LOG_TAG) << "setRate: " << rate << "\n";
@@ -441,8 +459,10 @@ void PcmStream::sendRequest(const std::string& method, const jsonrpcpp::Paramete
         return handler({ControlErrc::can_not_control});
 
     jsonrpcpp::Request req(++req_id_, method, params);
-    stream_ctrl_->command(req, [handler](const jsonrpcpp::Response& response) {
-        if (response.error().code())
+    stream_ctrl_->command(req,
+                          [handler](const jsonrpcpp::Response& response)
+                          {
+        if (response.error().code() != 0)
             handler({static_cast<ControlErrc>(response.error().code()), response.error().data()});
         else
             handler({ControlErrc::success});
@@ -463,15 +483,15 @@ void PcmStream::setProperties(const Properties& properties)
     if (props.metadata.has_value() && props.metadata->art_data.has_value() && !props.metadata->art_url.has_value())
     {
         auto data = base64_decode(props.metadata->art_data->data);
-        auto md5 = server_settings_.http.image_cache.setImage(getName(), std::move(data), props.metadata->art_data->extension);
+        auto md5 = ServerSettings::Http::image_cache.setImage(getName(), std::move(data), props.metadata->art_data->extension);
 
         std::stringstream url;
         url << "http://" << server_settings_.http.host << ":" << server_settings_.http.port << "/__image_cache?name=" << md5;
         props.metadata->art_url = url.str();
     }
-    else if (!props.metadata->art_data.has_value())
+    else if (!props.metadata.has_value() || !props.metadata->art_data.has_value())
     {
-        server_settings_.http.image_cache.clear(getName());
+        ServerSettings::Http::image_cache.clear(getName());
     }
 
     if (props == properties_)
