@@ -75,11 +75,13 @@ void TcpStream::do_connect()
 
     if (is_server_)
     {
-        acceptor_->async_accept([this](boost::system::error_code ec, tcp::socket socket) {
+        acceptor_->async_accept(
+            [this](boost::system::error_code ec, tcp::socket socket)
+            {
             if (!ec)
             {
                 LOG(DEBUG, LOG_TAG) << "New client connection\n";
-                stream_ = make_unique<tcp::socket>(move(socket));
+                stream_ = make_unique<tcp::socket>(std::move(socket));
                 on_connect();
             }
             else
@@ -92,7 +94,9 @@ void TcpStream::do_connect()
     {
         stream_ = make_unique<tcp::socket>(strand_);
         boost::asio::ip::tcp::endpoint endpoint(boost::asio::ip::address::from_string(host_), port_);
-        stream_->async_connect(endpoint, [this](const boost::system::error_code& ec) {
+        stream_->async_connect(endpoint,
+                               [this](const boost::system::error_code& ec)
+                               {
             if (!ec)
             {
                 LOG(DEBUG, LOG_TAG) << "Connected\n";
