@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2022  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,10 +19,13 @@
 #ifndef WATCH_DOG_HPP
 #define WATCH_DOG_HPP
 
-#include <boost/asio.hpp>
+// 3rd party headers
+#include <boost/asio/any_io_executor.hpp>
+#include <boost/asio/steady_timer.hpp>
+
+// standard headers
 #include <memory>
 
-namespace net = boost::asio;
 
 namespace streamreader
 {
@@ -41,7 +44,7 @@ public:
 class Watchdog
 {
 public:
-    Watchdog(const net::any_io_executor& executor, WatchdogListener* listener = nullptr);
+    Watchdog(const boost::asio::any_io_executor& executor, WatchdogListener* listener = nullptr);
     virtual ~Watchdog();
 
     void start(const std::chrono::milliseconds& timeout);
